********************************************************************************
* Created by Giselle Kolenic, gkolenic@umich.edu, University of Michigan
* Last updated 02/13/2025
* Purpose: 2025 Stata Biostatistics and Epidemology Virtual Symposium DSMB Report Creation
* Title: "Increase efficiency and reproducibility in clinical trial reporting with Stata Tools"
********************************************************************************

********************************************************************************
*Section 1.0
*Get Started
********************************************************************************

*set working directory
cd "C:\Users\gkolenic\Desktop\Stata Symposium 2025"

*version control 
version 18.0

*data cutoff date
*update this every reporting period
local dcd="2025JAN24"

*DSMB meeting date
*update this every reporting period
local DSMB_MD="2025MAR01"


********************************************************************************
*Section 2.0
*DSMB Report Creation Using putdocx Commands
********************************************************************************

*Start with a clean slate!
clear
putdocx clear

*Start the DSMB report 
putdocx begin, pagesize(letter) font(Helvetica, 12, black)

*DSMB Report Title Page ********************************************************
putdocx paragraph, style(Title)
putdocx text ("Stata Study DSMB Open Report")
putdocx paragraph, style(Subtitle)
putdocx text ("Meeting Date: `DSMB_MD'"), linebreak
putdocx text ("Data Cutoff Date: `dcd'"), linebreak 

*Executive Summary *************************************************************
putdocx paragraph, style(Heading1)
putdocx text ("Executive Summary")
putdocx paragraph
putdocx text ("This is the DSMB report executive summary for the fake Stata Study. An executive summary usually includes summary statistics that are presented in the tables, listings, and figures (TLFs) presented in this report. I can include a few examples here."), linebreak
putdocx text (""), linebreak 
*Obtain some summary statistics to include in the executive summary
*number of consented patients 
use Stata_Study_`dcd'.dta, clear 
local overall_N=_N
*male/female
use Stata_Study_`dcd'.dta, clear 
tab SEX_d1 if SEX_d1==1
local female=r(N)
tab SEX_d2 if SEX_d2==1
local male=r(N)
*age
use Stata_Study_`dcd'.dta, clear 
sum AGE2
local age=round(r(mean))
*Place these summary statistics in the executive summary
putdocx text ("There are a total of `overall_N' patients enrolled in the study from four sites as of `dcd'. Of the consented participants, `female' are female and `male' are male. The average participant age is `age'. Table 2 provides more information regarding patient demographics."), linebreak
putdocx text (""), linebreak 
*Obtain some summary statistics to include in the executive summary
*number of consented patients 
use Stata_Study_AE_`dcd'.dta, clear 
local AE_N=_N
egen SubAE=max(EVENT_ORDINAL)
sum SubAE
local SubAE=r(mean)
*Place these summary statistics in the executive summary
putdocx text ("Significant safety concerns have not been identified. There were `AE_N' treatment-emergent serious adverse events (SAEs) from `SubAE' patients in the safety population (`overall_N'). See Listing 1 for more details."), linebreak
putdocx text (""), linebreak
*pagebreak for TLFs
putdocx pagebreak 

*TLFs **************************************************************************
putdocx paragraph, style(Heading1)
putdocx text ("Tables, Listings, and Figures")

*Figure 1 ***********************************************************************
putdocx paragraph, style(Heading2)
putdocx text ("Figure 1. Stata Study Number of Consented Participants by Month. All Consented Participants.")
putdocx image Figure1_Final_`dcd'.png
*Add in footnote 
putdocx paragraph
putdocx text ("Data Cutoff Date: `dcd'"), linebreak font(Helvetica, 8, black)
putdocx text ("Report Date: `c(current_date)'"), linebreak font(Helvetica, 8, black)
putdocx text (""), linebreak 
*pagebreak for TLFs
putdocx pagebreak 

*Table 1 ***********************************************************************
putdocx paragraph, style(Heading2)
putdocx text ("Table 1. Stata Study Number of Consented Participants by Month and Site. All Consented Participants.")
use Table1_Final_`dcd'.dta, clear
*Extract N's for Table 1 headings 
*overall
sum N_CST, d
local overall_N=r(max)
*site 1
sum N_CST_site_1, d
local site1_N=r(max)
*site 2
sum N_CST_site_2, d
local site2_N=r(max)
*site 3
sum N_CST_site_3, d
local site3_N=r(max)
*site 4
sum N_CST_site_4, d
local site4_N=r(max)
*back to creating Table 1...
putdocx table Table1 = data(c_ym n_perc_overall n_perc_site_1 n_perc_site_2 n_perc_site_3 n_perc_site_4), varnames
putdocx table Table1(1,1)=("Month and Year"), halign(center)
putdocx table Table1(1,2)=("Overall (N=`overall_N')"), halign(center)
putdocx table Table1(1,3)=("Site 1 (N=`site1_N')"), halign(center)
putdocx table Table1(1,4)=("Site 2 (N=`site2_N')"), halign(center)
putdocx table Table1(1,5)=("Site 3 (N=`site3_N')"), halign(center)
putdocx table Table1(1,6)=("Site 4 (N=`site4_N')"), halign(center)
*Add in footnote 
putdocx paragraph
putdocx text ("Data Cutoff Date: `dcd'"), linebreak font(Helvetica, 8, black)
putdocx text ("Report Date: `c(current_date)'"), linebreak font(Helvetica, 8, black)
putdocx text (""), linebreak 
*pagebreak for TLFs
putdocx pagebreak 

*Table 2 ***********************************************************************
putdocx paragraph, style(Heading2)
putdocx text ("Table 2. Stata Study Demographic Characteristics. All Consented Participants.")
use Table2_Final_`dcd'.dta, clear
*maximum N = N for the table
sum N, d
local max_N=r(max)
*back to creating Table 2...
putdocx table Table2 = data(variable varlabel n_percent), varnames
putdocx table Table2(1,1)=("Variable"), halign(center)
putdocx table Table2(1,2)=("Statistic or Category"), halign(center)
putdocx table Table2(1,3)=("Overall (N=`max_N')"), halign(center)
*Add in footnote 
putdocx paragraph
putdocx text ("Data Cutoff Date: `dcd'"), linebreak font(Helvetica, 8, black)
putdocx text ("Report Date: `c(current_date)'"), font(Helvetica, 8, black)
putdocx text (""), linebreak 
*pagebreak for TLFs
putdocx pagebreak 

*Listing 1 *********************************************************************
putdocx paragraph, style(Heading2)
putdocx text ("Listing 1. Stata Study Treatment-Emergent SAEs. Safety Population.")
use Listing1_Final_`dcd'.dta, clear
putdocx table Listing1 = data(ID EVENT_ORDINAL AE_AETERM DURATION AE_SEV AE_OUT), varnames
putdocx table Listing1(1,1)=("Participant ID"), halign(center)
putdocx table Listing1(1,2)=("SAE #"), halign(center)
putdocx table Listing1(1,3)=("SAE Verbatim Term"), halign(center)
putdocx table Listing1(1,4)=("SAE Duration (Days)"), halign(center)
putdocx table Listing1(1,5)=("Severity Grade"), halign(center)
putdocx table Listing1(1,6)=("Outcome"), halign(center)
*Add in footnote 
putdocx paragraph
putdocx text ("Treatment-emergent serious adverse events are SAEs that began after the first dose of study medication."), linebreak font(Helvetica, 8, black)
putdocx text ("The Safety Population includes all randomized participants who received at least one dose of study medication."), linebreak font(Helvetica, 8, black)
putdocx text ("Data Cutoff Date: `dcd'"), linebreak font(Helvetica, 8, black)
putdocx text ("Report Date: `c(current_date)'"), linebreak font(Helvetica, 8, black)
putdocx text (""), linebreak

*All elements have been added **************************************************
*Place everything in the DSMB report  
putdocx save DSMB_open_`DSMB_MD', replace






